package com.muzhi.meidiai.controller;

import com.muzhi.meidiai.common.R;
import com.muzhi.meidiai.service.DingOaService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


@Api(description = "钉钉人事")
@RestController
@RequestMapping("/dingservice")
@CrossOrigin//解决跨域问题
public class DingOaController {

    @Autowired
    private DingOaService dingOaService;


    //获取宜搭审批实例详情（项目信息档案-根据OA审批提交人userid过滤）
    @ApiOperation(value = "表单加载时")
    @GetMapping("getXiangMuXX")
    public R getXiangMuXX(String userid){

        List xiangMuXX = dingOaService.getXiangMuXX(userid);

        return R.ok().data("result",xiangMuXX);
    }

    //获取宜搭审批实例详情（项目信息档案-根据连接器加载的项目列表选择某个项目时，加载项目编号、项目名称、项目负责人id、项目负责人名称到指定控件中）；【外出、加班】使用。
    @ApiOperation(value = "控件发生变化时")
    @GetMapping("getXiangMuID")
    public String getXiangMuID(String xmid){

        String xiangMuID = dingOaService.getXiangMuID(xmid);

//        return R.ok().data("result",xiangMuID);
        return xiangMuID;
    }

    //OA审批表单提交校验：判断当前离职审批发起人在宜搭中是否存在未结算项目，如有，则审批不通过，并弹窗提示：当前有未结算项目，请完成项目交接！
    @ApiOperation(value = "表单提交时校验")
    @GetMapping("getXiangMuJY")
    public Map getXiangMuJY(String userid){

        Map xiangMuJY = dingOaService.getXiangMuJY(userid);

        return xiangMuJY;
    }

    //OA【加班】审批表单提交校验：判断当前审批发起人提交【加班】时间是否跨天提交，如有，则审批不通过，并弹窗提示：不能跨天提交！
    @ApiOperation(value = "表单提交时校验")
    @GetMapping("getTimeJY")
    public Map getTimeJY(String startTime,String endTime){

        Map timeJY = dingOaService.getTimeJY(startTime,endTime);

        return timeJY;
    }

    /*
     * 保存宜搭表单数据【加班信息档案】
     * */
    @ApiOperation(value = "表单审批通过后触发")
    @PostMapping("createJBXX")
    public String createJBXX(String jbrid,
                             String kssj, String jssj,String jbsc,
                             String xmbh, String xmmc,
                             String jbsy, String djbh){

        String jbxx = dingOaService.createJBXX(jbrid,kssj,jssj,jbsc,xmbh,xmmc,jbsy,djbh);

        return jbxx;
    }

    //OA【加班】审批表单提交校验：判断当前审批发起人提交【加班】中关联的项目（编号）是否提交过审批（包含已提交、撤销、拒绝），
    // 如有，则审批不通过，并弹窗提示：当前项目你已提交过加班！
    @ApiOperation(value = "表单提交时校验")
    @GetMapping("getXiangMuIsNullJY")
    public Map getXiangMuIsNullJY(String userid,String xmbh,String startTime,String endTime){

        Map xiangMuJY = dingOaService.getXiangMuIsNullJY(userid,xmbh,startTime,endTime);

        return xiangMuJY;
    }

    /*
    * 抓取钉钉出差外勤打卡信息更新至宜搭【出差明细中间表】
    * 出差开始日期、出差结束日期、出差天数、出差补贴（结合岗位补贴标准字段*出差天数）
    * */
    @ApiOperation(value = "定时同步【出差明细中间表】")
    @PostMapping("updateChuchaiA")
    //    @Scheduled(cron = "0 0 12 * * ?")//每天中午12：00触发（也就是中午12点整触发）
    @Scheduled(cron = "0 5 6 * * ?")//每天06：05触发（也就是凌晨6点整触发）
    public String updateChuchaiA(){

        String s = dingOaService.updateChuchaiA();

        return s;
    }

    /*
     * 抓取钉钉出差外勤打卡信息更新至宜搭【项目预算档案】
     * 出差开始日期、出差结束日期、出差天数、出差补贴（结合岗位补贴标准字段*出差天数）
     * */
    @ApiOperation(value = "定时同步【项目预算档案】")
    @PostMapping("updateChuchaiB")
    //    @Scheduled(cron = "0 0 12 * * ?")//每天中午12：00触发（也就是中午12点整触发）
//    @Scheduled(cron = "0 5 7 * * ?")//每天07：05触发（也就是凌晨7点整触发）TODO 目前取消，只同步出差明细中间表
    public String updateChuchaiB(){

        String s = dingOaService.updateChuchaiB();

        return s;
    }
}